
## CATO-CLI - mutation.sites.removeSecondaryAzureVSocket:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.sites.removeSecondaryAzureVSocket) for documentation on this operation.

### Usage for mutation.sites.removeSecondaryAzureVSocket:

`catocli mutation sites removeSecondaryAzureVSocket -h`

`catocli mutation sites removeSecondaryAzureVSocket <json>`

`catocli mutation sites removeSecondaryAzureVSocket "$(cat < mutation.sites.removeSecondaryAzureVSocket.json)"`

`catocli mutation sites removeSecondaryAzureVSocket '{"socketId":"id"}'`

`catocli mutation sites removeSecondaryAzureVSocket -p '{
    "socketId": "id"
}'`


#### Operation Arguments for mutation.sites.removeSecondaryAzureVSocket ####

`accountId` [ID] - (required) N/A    
`socketId` [ID] - (required) N/A    
